# Welcome to geoca

[![image](https://img.shields.io/pypi/v/geoca.svg)](https://pypi.python.org/pypi/geoca)
[![image](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

<img src="assets/logo_long.png" alt="logo" style="zoom:30%;" />

**A Python module for CA models based on geo-raster data**

- Free software: MIT License
- Documentation: [https://Haorui-Jiang.github.io/geoca](https://Haorui-Jiang.github.io/geoca)

## Features

- Read raster data from a file and convert the data to a format such as a Python list.
- Creates a raster template from the input raster data and uniformly replaces the data in the corresponding position of that raster template.
- Running CA models based on raster data to analyze population and other resource migration.
